@@ -183,6 +183,12 @@ class DocumentPrivate
          */
         QVariant documentMetaData( const QString &key, const QVariant &option ) const;
 
+        /**
+         * Return whether the normalized rectangle @p rectOfInterest on page number @p rectPage
+         * is fully visible.
+         */
+        bool isNormalizedRectangleFullyVisible( const Okular::NormalizedRect & rectOfInterest, int rectPage );
+
         // member variables
         Document *m_parent;
         QPointer<QWidget> m_widget;
@@ -210,9 +216,6 @@ class DocumentPrivate
 
         // observers / requests / allocator stuff
         QSet< DocumentObserver * > m_observers;
-        // FIXME This is a hack, we need to support
-        // multiple tiled observers, but for the moment we only support one
-        DocumentObserver *m_tiledObserver;
         QLinkedList< PixmapRequest * > m_pixmapRequestsStack;
         QLinkedList< PixmapRequest * > m_executingPixmapRequests;
         QMutex m_pixmapRequestsMutex;
