@@ -26,7 +26,6 @@
 #include <kconfig.h>
 #include <kglobal.h>
 #include <klocale.h>
-#include <kmessagebox.h>
 #include <kmimetype.h>
 #include <kstandarddirs.h>
 #include <kvbox.h>
@@ -73,10 +72,9 @@ dviRenderer::dviRenderer(bool useFontHinting)
   //kDebug(kvs::dvi) << "dviRenderer( parent=" << par << " )";
 #endif
 
-//  connect(&font_pool, SIGNAL(setStatusBarText(QString)), this, SIGNAL(setStatusBarText(QString)) );
-//  connect( &clearStatusBarTimer, SIGNAL(timeout()), this, SLOT(clearStatusBar()) );
-  // pass status bar messages through
-//  connect(PS_interface, SIGNAL(setStatusBarText(QString)), this, SIGNAL(setStatusBarText(QString)) );
+  connect( &font_pool, SIGNAL( error(QString,int) ), this, SIGNAL( error(QString,int) ) );
+  connect( &font_pool, SIGNAL( warning(QString,int) ), this, SIGNAL( warning(QString,int) ) );
+  connect( PS_interface, SIGNAL( error(QString,int) ), this, SIGNAL( error(QString,int) ) );
 }
 
 
@@ -101,14 +99,6 @@ void dviRenderer::setPrefs(bool flag_showPS, const QString &str_editorCommand, b
   font_pool.setParameters( useFontHints );
 }
 
-
-void dviRenderer::showInfo()
-{
-  QMutexLocker locker(&mutex);
-
-  info->setDVIData(dviFile);
-  info->show();
-}
 #endif
 
 
@@ -225,17 +215,13 @@ void dviRenderer::drawPage(RenderedDocumentPagePixmap* page)
     }
   }
 
-#if 0
-  page->isEmpty = false;
   if (errorMsg.isEmpty() != true) {
-    KMessageBox::detailedError(parentWidget,
-                               i18n("<qt><strong>File corruption</strong> Okular could not interpret your DVI file. This is "
-                                    "most commonly caused by a corrupted file.</qt>"),
-                               errorMsg, i18n("DVI File Error"));
+    emit error(i18n("File corruption. %1", errorMsg), -1);
     errorMsg.clear();
     currentlyDrawnPage = 0;
     return;
   }
+#if 0
 
   // Tell the user (once) if the DVI file contains source specials
   // ... we don't want our great feature to go unnoticed.
@@ -361,13 +347,12 @@ void dviRenderer::embedPostScript()
   embedPS_progress = 0;
 
   if (!errorMsg.isEmpty()) {
-    errorMsg = "<qt>" + errorMsg + "</qt>";
-//    KMessageBox::detailedError(parentWidget, "<qt>" + i18n("Not all PostScript files could be embedded into your document.") + "</qt>", errorMsg);
+    emit warning(i18n("Not all PostScript files could be embedded into your document. %1", errorMsg), -1);
     errorMsg.clear();
-  } else
-/*    KMessageBox::information(parentWidget, "<qt>" + i18n("All external PostScript files were embedded into your document. You "
-                                                 "will probably want to save the DVI file now.") + "</qt>",
-                             QString(), "embeddingDone");*/
+  } else {
+    emit notice(i18n("All external PostScript files were embedded into your document."), -1);
+  }
+
 
   // Prescan phase starts here
 #ifdef PERFORMANCE_MEASUREMENT
@@ -445,8 +430,6 @@ bool dviRenderer::setFile(const QString &fname, const KUrl &base)
   // the dvifile and the pixmap.
   if (fname.isEmpty()) {
     // Delete DVI file
-/*    if(info)
-      info->setDVIData(0);*/
     delete dviFile;
     dviFile = 0;
     return true;
@@ -455,13 +438,8 @@ bool dviRenderer::setFile(const QString &fname, const KUrl &base)
 
   // Make sure the file actually exists.
   if (!fi.exists() || fi.isDir()) {
-/*
-    KMessageBox::error( parentWidget,
-                        i18n("<qt><strong>File error.</strong> The specified file '%1' does not exist. "
-                             "KDVI already tried to add the ending '.dvi'.</qt>", filename),
-                        i18n("File Error"));
-*/
-	  return false;
+    emit error(i18n("The specified file '%1' does not exist.", filename), -1);
+    return false;
   }
 
   QApplication::setOverrideCursor( Qt::WaitCursor );
@@ -475,10 +453,7 @@ bool dviRenderer::setFile(const QString &fname, const KUrl &base)
   if ((dviFile_new->dvi_Data() == NULL)||(dviFile_new->errorMsg.isEmpty() != true)) {
     QApplication::restoreOverrideCursor();
     if (dviFile_new->errorMsg.isEmpty() != true)
-/*      KMessageBox::detailedError(parentWidget,
-                                 i18n("<qt>File corruption. KDVI could not interprete your DVI file. This is "
-                                      "most commonly caused by a corrupted file.</qt>"),
-                                 dviFile_new->errorMsg, i18n("DVI File Error"));*/
+      emit error(i18n("File corruption. %1", dviFile_new->errorMsg), -1);
     delete dviFile_new;
     return false;
   }
@@ -486,8 +461,6 @@ bool dviRenderer::setFile(const QString &fname, const KUrl &base)
   delete dviFile;
   dviFile = dviFile_new;
   numPages = dviFile->total_pages;
-  /* if(info)
-    info->setDVIData(dviFile); */
   _isModified = false;
   baseURL = base;
 
@@ -523,10 +496,6 @@ bool dviRenderer::setFile(const QString &fname, const KUrl &base)
   // Locate fonts.
   font_pool.locateFonts();
 
-  // Update the list of fonts in the info window
-  //if (info != 0)
-    //info->setFontInfo(&font_pool);
-
   // We should pre-scan the document now (to extract embedded,
   // PostScript, Hyperlinks, ets).
 
@@ -631,14 +600,10 @@ Anchor dviRenderer::parseReference(const QString &reference)
     QString  refFileName   = splitter.filePath();
 
     if (sourceHyperLinkAnchors.isEmpty()) {
-/*
-      KMessageBox::sorry(parentWidget, i18n("<qt>You have asked KDVI to locate the place in the DVI file which corresponds to "
-                                    "line %1 in the TeX-file <strong>%2</strong>. It seems, however, that the DVI file "
-                                    "does not contain the necessary source file information. "
-                                    "We refer to the manual of KDVI for a detailed explanation on how to include this "
-                                    "information. Press the F1 key to open the manual.</qt>", refLineNumber, refFileName),
-                         i18n("Could Not Find Reference"));
-*/
+      emit warning(i18n("You have asked Okular to locate the place in the DVI file which corresponds to "
+                        "line %1 in the TeX-file %2. It seems, however, that the DVI file "
+                        "does not contain the necessary source file information. ",
+                        refLineNumber, refFileName), -1);
       return Anchor();
     }
 
@@ -675,11 +640,8 @@ Anchor dviRenderer::parseReference(const QString &reference)
     else
       if (anchorForRefFileFound == false)
       {
-/*
-        KMessageBox::sorry(parentWidget, i18n("<qt>KDVI was not able to locate the place in the DVI file which corresponds to "
-                                              "line %1 in the TeX-file <strong>%2</strong>.</qt>", refLineNumber, refFileName),
-                           i18n( "Could Not Find Reference" ));
-*/
+        emit warning(i18n("Okular was not able to locate the place in the DVI file which corresponds to "
+                          "line %1 in the TeX-file %2.", refLineNumber, refFileName), -1);
       }
       else
         return Anchor();
@@ -706,12 +668,6 @@ void dviRenderer::setResolution(double resolution_in_DPI)
 }
 
 
-void dviRenderer::clearStatusBar()
-{
-  //emit setStatusBarText( QString() );
-}
-
-
 void dviRenderer::handleSRCLink(const QString &linkText, const QPoint& point, DocumentWidget *win)
 {
   Q_UNUSED( linkText );
@@ -775,14 +731,6 @@ void dviRenderer::exportPS(const QString& fname, const QStringList& options, QPr
 }
 
 /*
-void dviRenderer::update_info_dialog(const QString& text, bool clear)
-{
-  if (clear)
-    info->clear(text);
-  else
-    info->outputReceiver(text);
-}
-
 void dviRenderer::editor_finished(const DVISourceEditor*)
 {
   editor_.attach(0);
