@@ -26,6 +26,7 @@
 #include "fontprogress.h"
 #include "kvs_debug.h"
 
+#include <KStandardDirs>
 #include <kfiledialog.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -46,7 +47,9 @@ DVIExport::DVIExport(dviRenderer& parent, QWidget* parent_widget)
     progress_(0),
     parent_(&parent),
     parent_widget_(parent_widget)
-{}
+{
+  connect( this, SIGNAL(error(QString,int)), &parent, SIGNAL(error(QString,int)) );
+}
 
 
 DVIExport::~DVIExport()
@@ -137,7 +140,7 @@ void DVIExport::finished_impl(int exit_code)
   }
 
   if (process_ && exit_code != 0)
-    KMessageBox::error(parent_widget_, error_message_);
+    emit error(error_message_, -1);
   // Remove this from the store of all export processes.
   parent_->m_eventLoop->exit( exit_code );
   parent_->export_finished(this);
@@ -148,75 +151,13 @@ void DVIExport::output_receiver()
 {
   if (process_) {
      QString out = process_->readAllStandardOutput();
-#if 0
-    parent_->update_info_dialog(process_->readAll());
-#endif
+
     if (progress_)
       progress_->show();
   }
 }
 
 
-namespace {
-
-/** @returns the contents of environment variable @c envname as a
- *  QStringList split at the OS-dependent path separator.
- *  (':' on *nix, ';' on Windows.
- */
-const QStringList get_env_path(const char* envname)
-{
-  if (!envname || !*envname)
-    return QStringList();
-
-#if defined _WIN32
-  const char path_separator = ';';
-#else
-  const char path_separator = ':';
-#endif
-
-  const char* const envvar = ::getenv(envname);
-  if (!envvar || !*envvar)
-    return QStringList();
-
-  return QString(envvar).split(path_separator);
-}
-
-
-/** @returns true if the file @c exe_ can be found in the PATH
- *  and is executable.
- */
-bool find_exe(const QString& exe_)
-{
-#if defined _WIN32
-  const QFileInfo exe(exe_.endsWith(".exe") ? exe_ : exe_ + ".exe");
-#else
-  const QFileInfo exe(exe_);
-#endif
-
-  if (exe.isAbsolute())
-    return exe.exists() && exe.isReadable() && exe.isExecutable();
-
-  const QStringList path = get_env_path("PATH");
-  if (path.isEmpty())
-    return false;
-
-  typedef QStringList::const_iterator iterator;
-
-  const iterator end = path.end();
-  for (iterator it = path.begin(); it != end; ++it) {
-    const QString dir = it->endsWith("/") ? *it : *it + '/';
-    const QFileInfo abs_exe = QString(dir + exe.filePath());
-
-    if (abs_exe.exists())
-      return abs_exe.isReadable() && abs_exe.isExecutable();
-  }
-
-  return false;
-}
-
-} // namespace anon
-
-
 DVIExportToPDF::DVIExportToPDF(dviRenderer& parent, QWidget* parent_widget)
   : DVIExport(parent, parent_widget)
 {
@@ -229,16 +170,15 @@ DVIExportToPDF::DVIExportToPDF(dviRenderer& parent, QWidget* parent_widget)
   if (!input.exists() || !input.isReadable())
     return;
 
-  if (!find_exe("dvipdfm")) {
-    KMessageBox::sorry(parent_widget,
-                               i18n("Okular could not locate the program 'dvipdfm' on your computer. This program is "
-                               "essential for the export function to work. You can, however, convert "
-                               "the DVI-file to PDF using the print function of Okular, but that will often "
-                               "produce documents which print okay, but are of inferior quality if viewed in "
-                               "Acrobat Reader. It may be wise to upgrade to a more recent version of your "
-                               "TeX distribution which includes the 'dvipdfm' program.\n"
-                               "Hint to the perplexed system administrator: Okular uses the PATH environment variable "
-                               "when looking for programs."));
+  if (KStandardDirs::findExe("dvipdfm").isEmpty()) {
+    emit error(i18n("Okular could not locate the program 'dvipdfm' on your computer. This program is "
+                    "essential for the export function to work. You can, however, convert "
+                    "the DVI-file to PDF using the print function of Okular, but that will often "
+                    "produce documents which print okay, but are of inferior quality if viewed in "
+                    "Acrobat Reader. It may be wise to upgrade to a more recent version of your "
+                    "TeX distribution which includes the 'dvipdfm' program.\n"
+                    "Hint to the perplexed system administrator: Okular uses the PATH environment variable "
+                    "when looking for programs."), -1);
     return;
   }
 
@@ -267,11 +207,6 @@ DVIExportToPDF::DVIExportToPDF(dviRenderer& parent, QWidget* parent_widget)
                                   "Please be patient."),
                              i18n("Waiting for dvipdfm to finish...") );
 
-#if 0
-  parent.update_info_dialog(i18n("Export: %1 to PDF", dvi.filename),
-                              true);
-#endif
-
   start("dvipdfm",
         QStringList() << "-o"
                       << output_name
@@ -307,23 +242,17 @@ DVIExportToPS::DVIExportToPS(dviRenderer& parent,
     return;
 
   if (dvi.numberOfExternalNONPSFiles != 0) {
-    KMessageBox::sorry(parent_widget,
-                       i18n("<qt><P>This DVI file refers to external graphic files which are not in PostScript format, and cannot be handled by the "
-                            "<strong>dvips</strong> program that Okular uses internally to print or to export to PostScript. The functionality that "
-                            "you require is therefore unavailable in this version of Okular.</p>"
-                            "<p>As a workaround, you can use the <strong>File/Export As</strong>-Menu to save this file in PDF format, and then use "
-                            "a PDF viewer.</p>"
-                            "<p>It is planned to add this functionality at a later date.</p></qt>") ,
-                       i18n("Functionality Unavailable"));
+    emit error(i18n("This DVI file refers to external graphic files which are not in PostScript format, and cannot be handled by the "
+                    "'dvips' program that Okular uses internally to print or to export to PostScript. The functionality that "
+                    "you require is therefore unavailable in this version of Okular."), -1);
     return;
   }
 
-  if (!find_exe("dvips")) {
-    KMessageBox::sorry(parent_widget,
-                          i18n("Okular could not locate the program 'dvips' on your computer. That program is "
-                               "essential for the export function to work.\n"
-                               "Hint to the perplexed system administrator: Okular uses the PATH environment variable "
-                               "when looking for programs."));
+  if (KStandardDirs::findExe("dvips").isEmpty()) {
+    emit error(i18n("Okular could not locate the program 'dvips' on your computer. That program is "
+                    "essential for the export function to work.\n"
+                    "Hint to the perplexed system administrator: Okular uses the PATH environment variable "
+                    "when looking for programs."), -1);
     return;
   }
 
@@ -427,11 +356,6 @@ DVIExportToPS::DVIExportToPS(dviRenderer& parent,
                                   "Please be patient."),
                              i18n("Waiting for dvips to finish...") );
 
-#if 0
-  parent.update_info_dialog(i18n("Export: %1 to PostScript", dvi.filename),
-                              true);
-#endif
-
   QStringList args;
   if (!printer)
     // Export hyperlinks
