@@ -30,10 +30,11 @@ namespace Epub {
 
       void _emitData(Okular::DocumentInfo::Key key, enum epub_metadata type); 
       void _handle_anchors(const QTextBlock &start, const QString &name);
+      void _insert_local_links(const QString &key, const QPair<int, int> &value);
       EpubDocument *mTextDocument;
 
       QHash<QString, QTextBlock> mSectionMap;
-      QHash<QString, QPair<int, int> > mLocalLinks;
+      QHash<QString, QVector< QPair<int, int> > > mLocalLinks;
     };
 }
 
