@@ -23,6 +23,8 @@
 #include <kimageio.h>
 #include <klocale.h>
 
+#include <libkexiv2/kexiv2.h>
+
 #include <core/page.h>
 
 static KAboutData createAboutData()
@@ -31,7 +33,7 @@ static KAboutData createAboutData()
          "okular_kimgio",
          "okular_kimgio",
          ki18n( "Image Backend" ),
-         "0.1.1",
+         "0.1.2",
          ki18n( "A simple image backend" ),
          KAboutData::License_GPL,
          ki18n( "© 2005, 2009 Albert Astals Cid\n"
@@ -51,6 +53,7 @@ KIMGIOGenerator::KIMGIOGenerator( QObject *parent, const QVariantList &args )
 {
     setFeature( ReadRawData );
     setFeature( Threaded );
+    setFeature( TiledRendering );
     setFeature( PrintNative );
     setFeature( PrintToFile );
 
@@ -82,6 +85,12 @@ bool KIMGIOGenerator::loadDocument( const QString & fileName, QVector<Okular::Pa
     }
     docInfo.set( Okular::DocumentInfo::MimeType, mime );
 
+    // Apply transformations dictated by Exif metadata
+    KExiv2Iface::KExiv2 exifMetadata;
+    if ( exifMetadata.load( fileName ) ) {
+        exifMetadata.rotateExifQImage( m_img, exifMetadata.getImageOrientation() );
+    }
+
     pagesVector.resize( 1 );
 
     Okular::Page * page = new Okular::Page( 0, m_img.width(), m_img.height(), Okular::Rotation0 );
@@ -107,6 +116,12 @@ bool KIMGIOGenerator::loadDocumentFromData( const QByteArray & fileData, QVector
     }
     docInfo.set( Okular::DocumentInfo::MimeType, mime );
 
+    // Apply transformations dictated by Exif metadata
+    KExiv2Iface::KExiv2 exifMetadata;
+    if ( exifMetadata.loadFromData( fileData ) ) {
+        exifMetadata.rotateExifQImage( m_img, exifMetadata.getImageOrientation() );
+    }
+
     pagesVector.resize( 1 );
 
     Okular::Page * page = new Okular::Page( 0, m_img.width(), m_img.height(), Okular::Rotation0 );
@@ -125,12 +140,29 @@ bool KIMGIOGenerator::doCloseDocument()
 QImage KIMGIOGenerator::image( Okular::PixmapRequest * request )
 {
     // perform a smooth scaled generation
-    int width = request->width();
-    int height = request->height();
-    if ( request->page()->rotation() % 2 == 1 )
-        qSwap( width, height );
+    if ( request->isTile() )
+    {
+        const QRect srcRect = request->normalizedRect().geometry( m_img.width(), m_img.height() );
+        const QRect destRect = request->normalizedRect().geometry( request->width(), request->height() );
 
-    return m_img.scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+        QImage destImg( destRect.size(), QImage::Format_RGB32 );
+        destImg.fill( Qt::white );
+
+        QPainter p( &destImg );
+        p.setRenderHint( QPainter::SmoothPixmapTransform );
+        p.drawImage( destImg.rect(), m_img, srcRect );
+
+        return destImg;
+    }
+    else
+    {
+        int width = request->width();
+        int height = request->height();
+        if ( request->page()->rotation() % 2 == 1 )
+            qSwap( width, height );
+
+        return m_img.scaled( width, height, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+    }
 }
 
 bool KIMGIOGenerator::print( QPrinter& printer )
