@@ -89,7 +89,6 @@
 #include "core/annotations.h"
 #include "core/bookmarkmanager.h"
 #include "core/document.h"
-#include "core/document_p.h"
 #include "core/generator.h"
 #include "core/page.h"
 #include "core/fileprinter.h"
@@ -347,6 +346,7 @@ m_cliPresentation(false), m_cliPrint(false), m_embedMode(detectEmbedMode(parentW
 
     m_sidebar = new Sidebar( parentWidget );
     setWidget( m_sidebar );
+    connect( m_sidebar, SIGNAL(urlsDropped(KUrl::List)), SLOT(handleDroppedUrls(KUrl::List)) );
 
     // build the document
     m_document = new Okular::Document(widget());
@@ -383,7 +383,6 @@ m_cliPresentation(false), m_cliPrint(false), m_embedMode(detectEmbedMode(parentW
     m_searchWidget = new SearchWidget( thumbsBox, m_document );
     m_thumbnailList = new ThumbnailList( thumbsBox, m_document );
     //	ThumbnailController * m_tc = new ThumbnailController( thumbsBox, m_thumbnailList );
-    connect( m_thumbnailList, SIGNAL(urlDropped(KUrl)), SLOT(openUrlFromDocument(KUrl)) );
     connect( m_thumbnailList, SIGNAL(rightClick(const Okular::Page*,QPoint)), this, SLOT(slotShowMenu(const Okular::Page*,QPoint)) );
     tbIndex = m_sidebar->addItem( thumbsBox, KIcon( "view-preview" ), i18n("Thumbnails") );
     m_sidebar->setCurrentIndex( tbIndex );
@@ -432,10 +431,8 @@ m_cliPresentation(false), m_cliPrint(false), m_embedMode(detectEmbedMode(parentW
     m_formsMessage = new PageViewTopMessage( rightContainer );
     rightLayout->addWidget( m_formsMessage );
     m_pageView = new PageView( rightContainer, m_document );
-    m_document->d->m_tiledObserver = m_pageView;
     QMetaObject::invokeMethod( m_pageView, "setFocus", Qt::QueuedConnection );      //usability setting
 //    m_splitter->setFocusProxy(m_pageView);
-    connect( m_pageView, SIGNAL(urlDropped(KUrl)), SLOT(openUrlFromDocument(KUrl)));
     connect( m_pageView, SIGNAL(rightClick(const Okular::Page*,QPoint)), this, SLOT(slotShowMenu(const Okular::Page*,QPoint)) );
     connect( m_document, SIGNAL(error(QString,int)), m_pageView, SLOT(errorMessage(QString,int)) );
     connect( m_document, SIGNAL(warning(QString,int)), m_pageView, SLOT(warningMessage(QString,int)) );
@@ -703,10 +700,10 @@ void Part::setupViewerActions()
     reload->setShortcut( KStandardShortcut::reload() );
     m_reload = reload;
 
-    m_closeFindBar = new KAction( i18n( "Close &Find Bar" ), ac );
-    ac->addAction("close_find_bar", m_closeFindBar);
-    connect(m_closeFindBar, SIGNAL(triggered()), this, SLOT(slotHideFindBar()));
-    widget()->addAction(m_closeFindBar);
+    m_closeFindBar = ac->addAction( "close_find_bar", this, SLOT(slotHideFindBar()) );
+    m_closeFindBar->setText( i18n("Close &Find Bar") );
+    m_closeFindBar->setShortcut( QKeySequence(Qt::Key_Escape) );
+    m_closeFindBar->setEnabled( false );
 
     KAction *pageno = new KAction( i18n( "Page Number" ), ac );
     pageno->setDefaultWidget( m_pageNumberTool );
@@ -825,6 +822,10 @@ void Part::setupActions()
     ac->addAction( "options_configure_annotations", configureAnnotations );
     configureAnnotations->setIcon( KIcon( "configure" ) );
     connect(configureAnnotations, SIGNAL(triggered()), this, SLOT(slotAnnotationPreferences()));
+
+    KAction *playPauseAction = new KAction( i18n( "Play/Pause Presentation" ), ac );
+    ac->addAction( "presentation_play_pause", playPauseAction );
+    playPauseAction->setEnabled( false );
 }
 
 Part::~Part()
@@ -942,6 +943,11 @@ void Part::setShowSourceLocationsGraphically(bool show)
     m_pageView->setShowSourceLocationsGraphically(show);
 }
 
+bool Part::openNewFilesInTabs() const
+{
+    return Okular::Settings::self()->shellOpenFileInTabs();
+}
+
 void Part::slotHandleActivatedSourceReference(const QString& absFileName, int line, int col, bool *handled)
 {
     emit openSourceReference( absFileName, line, col );
@@ -982,6 +988,20 @@ void Part::openUrlFromBookmarks(const KUrl &_url)
         openUrl( url );
 }
 
+void Part::handleDroppedUrls( const KUrl::List& urls )
+{
+    if ( urls.isEmpty() )
+        return;
+
+    if ( m_embedMode != NativeShellMode || !openNewFilesInTabs() )
+    {
+        openUrlFromDocument( urls.first() );
+        return;
+    }
+
+    emit urlsDropped( urls );
+}
+
 void Part::slotJobStarted(KIO::Job *job)
 {
     if (job)
@@ -1226,6 +1246,8 @@ bool Part::openFile()
     }
     bool canSearch = m_document->supportsSearching();
 
+    emit mimeTypeChanged( mime );
+
     // update one-time actions
     emit enableCloseAction( ok );
     m_find->setEnabled( ok && canSearch );
@@ -1790,7 +1812,7 @@ void Part::slotShowFindBar()
 {
     m_findBar->show();
     m_findBar->focusAndSetCursor();
-    m_closeFindBar->setShortcut( QKeySequence( Qt::Key_Escape ) );
+    m_closeFindBar->setEnabled( true );
 }
 
 void Part::slotHideFindBar()
@@ -1798,7 +1820,7 @@ void Part::slotHideFindBar()
     if ( m_findBar->maybeHide() )
     {
         m_pageView->setFocus();
-        m_closeFindBar->setShortcut( QKeySequence( /* None */ ) );
+        m_closeFindBar->setEnabled( false );
     }
 }
 
