@@ -82,7 +82,7 @@ enum EmbedMode
     NativeShellMode,         // embedded in the native Okular' shell
     PrintPreviewMode,        // embedded to show the print preview of a document
     KHTMLPartMode,           // embedded in KHTML
-    ViewerWidgetMode,        // the part acts as a widget that can display all kinds of documents
+    ViewerWidgetMode         // the part acts as a widget that can display all kinds of documents
 };
 
 /**
@@ -132,6 +132,7 @@ class OKULAR_PART_EXPORT Part : public KParts::ReadWritePart, public Okular::Doc
         void setWatchFileModeEnabled(bool enable);
         bool areSourceLocationsShownGraphically() const;
         void setShowSourceLocationsGraphically(bool show);
+        bool openNewFilesInTabs() const;
 
     public slots:                // dbus
         Q_SCRIPTABLE Q_NOREPLY void goToPage(uint page);
@@ -156,6 +157,8 @@ class OKULAR_PART_EXPORT Part : public KParts::ReadWritePart, public Okular::Doc
         void openSourceReference(const QString& absFileName, int line, int column);
         void viewerMenuStateChange(bool enabled);
         void enableCloseAction(bool enable);
+        void mimeTypeChanged(KMimeType::Ptr mimeType);
+        void urlsDropped( const KUrl::List& urls );
 
     protected:
         // reimplemented from KParts::ReadWritePart
@@ -174,6 +177,7 @@ class OKULAR_PART_EXPORT Part : public KParts::ReadWritePart, public Okular::Doc
         // connected to actions
         void openUrlFromDocument(const KUrl &url);
         void openUrlFromBookmarks(const KUrl &url);
+        void handleDroppedUrls( const KUrl::List& urls );
         void slotGoToPage();
         void slotHistoryBack();
         void slotHistoryNext();
